@@ -95,7 +95,7 @@ impl Action {
         if self.argument().is_some() {
             self.argument().unwrap().get()
         } else {
-            panic!("Action has no argument");
+            panic!("Action '{}' has no argument", self.name());
         }
     }
 }
